Module col

Module col 

Col is a wrapper over Seq for an arbitrary sized datatype so it can be represented as its bytes and stored in a file using the Seq interface.

Structs

Col
Col implements a storage for the data of type T. It supports push, get, update asynchronous methods and their multiple extensions.