Module dataset

Module dataset 

Dataset is an alias for HashMap that keeps vectors of basic data (provided as Dataunit) by keys, so it represents a common dataset having columns (the keys) and rows.

Functions

get_dataset_size
Get size of the dataset. It works correctly for valid datasets because the function returns the length of the first vector. Otherwise it returns error.

Type Aliases

Dataset
Dataset is an alias for the HashMap of strings as keys vectors of Dataunit as values. Since Dataunit is an enum over integers, float and strings, they are the supported datatypes for the dataset.