Heap

Struct Heap 

pub struct Heap { /* private fields */ }
Asynchronous file-backed heap allocator.

Manages variable-sized memory blocks within a file.

Implementations

Source

impl Heap

pub async fn new(path: impl AsRef<Path>) -> TokioResult<Self>

Opens or creates a heap file at the given path.

pub async fn size(&self) -> TokioResult<usize>

Returns the current size of the heap file in bytes.

pub async fn alloc(&self, size: u64) -> TokioResult<HeapItem>

Allocates a new memory block of the given size.

pub async fn realloc(&self, item: &mut HeapItem, size: u64) -> TokioResult<bool>

Resizes the memory block. Reallocates if the new size exceeds the block’s capacity. It returns true if reallocation happened else false.

pub async fn update(&mut self, item: &HeapItem, block: &[u8]) -> TokioResult<()>

Writes data to the specified memory block.

pub async fn get( &mut self, item: &HeapItem, block: &mut [u8], ) -> TokioResult<()>

Reads data from the specified memory block.