Col is a wrapper over Seq for an arbitrary sized datatype so it can be
represented as its bytes and stored in a file using the Seq interface.
Structs
- Col
Colimplements a storage for the data of typeT. It supportspush,get,updateasynchronous methods and their multiple extensions.